« get me outta code hell

hsmusic-wiki - HSMusic - static wiki software cataloguing collaborative creation
about summary refs log tree commit diff
path: root/src/data/things/composite.js
diff options
context:
space:
mode:
Diffstat (limited to 'src/data/things/composite.js')
-rw-r--r--src/data/things/composite.js5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/data/things/composite.js b/src/data/things/composite.js
index fd52aa0f..29f5770c 100644
--- a/src/data/things/composite.js
+++ b/src/data/things/composite.js
@@ -853,8 +853,9 @@ export function exposeConstant({
 // consider using instead. Customize {mode} to select one of these modes,
 // or leave unset and default to 'null':
 //
 // * 'null':  Check that the value isn't null.
 // * 'empty': Check that the value is neither null nor an empty array.
+//            This will outright error for undefined.
 // * 'falsy': Check that the value isn't false when treated as a boolean
 //            (nor an empty array). Keep in mind this will also be false
 //            for values like zero and the empty string!
@@ -879,7 +880,7 @@ export function withResultOfAvailabilityCheck({
 
   const checkAvailability = (value, mode) => {
     switch (mode) {
-      case 'null': return value !== null;
+      case 'null': return value !== null && value !== undefined;
       case 'empty': return !empty(value);
       case 'falsy': return !!value && (!Array.isArray(value) || !empty(value));
       default: return false;
@@ -853,8 +853,9 @@ export function exposeConstant({
 // or leave unset and default to 'null':
 //
-// * 'null':  Check that the value isn't null.
+// * 'null':  Check that the value isn't null (and not undefined either).
 // * 'empty': Check that the value is neither null nor an empty array.